@@ -9,6 +9,7 @@ from __future__ import annotations
 import functools
 import heapq
 import importlib
+import math
 import numbers
 import platform
 import random
@@ -17,7 +18,21 @@ import string
 import warnings
 from decimal import Decimal
 from types import ModuleType
-from typing import Any, Dict, Hashable, Iterable, Iterator, List, Sequence, Set, Tuple, TypeVar, Union, overload
+from typing import (
+    Any,
+    Dict,
+    Hashable,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Sequence,
+    Set,
+    Tuple,
+    TypeVar,
+    Union,
+    overload,
+)
 from urllib.parse import quote
 
 import cognite.client
@@ -28,6 +43,10 @@ T = TypeVar("T")
 THashable = TypeVar("THashable", bound=Hashable)
 
 
+def is_unlimited(limit: Optional[Union[float, int]]) -> bool:
+    return limit in {None, -1, math.inf}
+
+
 @functools.lru_cache(maxsize=128)
 def to_camel_case(snake_case_string: str) -> str:
     components = snake_case_string.split("_")
@@ -54,6 +73,28 @@ def basic_obj_dump(obj: Any, camel_case: bool) -> Dict[str, Any]:
     return convert_all_keys_to_snake_case(vars(obj))
 
 
+def handle_deprecated_camel_case_argument(new_arg: T, old_arg_name: str, fn_name: str, kw_dct: Dict[str, Any]) -> T:
+    old_arg = kw_dct.pop(old_arg_name, None)
+    if kw_dct:
+        raise TypeError(f"Got unexpected keyword argument(s): {list(kw_dct)}")
+
+    new_arg_name = to_snake_case(old_arg_name)
+    if old_arg is None:
+        if new_arg is None:
+            raise TypeError(f"{fn_name}() missing 1 required positional argument: '{new_arg_name}'")
+        return new_arg
+
+    warnings.warn(
+        f"Argument '{old_arg_name}' have been changed to '{new_arg_name}', but the old is still supported until "
+        "the next major version. Consider updating your code.",
+        UserWarning,
+        stacklevel=2,
+    )
+    if new_arg is not None:
+        raise TypeError(f"Pass either '{new_arg_name}' or '{old_arg_name}' (deprecated), not both")
+    return old_arg
+
+
 def json_dump_default(x: Any) -> Any:
     if isinstance(x, numbers.Integral):
         return int(x)
@@ -65,6 +106,7 @@ def json_dump_default(x: Any) -> Any:
 
 
 def unwrap_identifer(identifier: Union[str, int, Dict]) -> Union[str, int]:
+    # TODO: Move to Identifier class?
     if isinstance(identifier, (str, int)):
         return identifier
     if "externalId" in identifier:
@@ -211,7 +253,7 @@ def convert_true_match(true_match: Union[dict, list, Tuple[Union[int, str], Unio
 def find_duplicates(seq: Iterable[THashable]) -> Set[THashable]:
     seen: Set[THashable] = set()
     add = seen.add  # skip future attr lookups for perf
-    return set(x for x in seq if x in seen or add(x))
+    return {x for x in seq if x in seen or add(x)}
 
 
 def exactly_one_is_not_none(*args: Any) -> bool:
